Algorithm

Enum Algorithm 

pub enum Algorithm {
    MlKem(MlKem),
    MlDsa(MlDsa),
    SlhDsa(SlhDsa),
}
A unified enum representing any supported PQ algorithm.

This provides a single type that can represent any algorithm from any family, useful for generic processing.

Example

use pq_oid::{Algorithm, MlKem, MlDsa};
use std::str::FromStr;

let alg = Algorithm::from_str("ML-KEM-512").unwrap();
assert_eq!(alg.oid(), "2.16.840.1.101.3.4.4.1");

// Convert from family-specific enums
let alg: Algorithm = MlDsa::Dsa65.into();
assert_eq!(alg.as_str(), "ML-DSA-65");

Variants



MlKem(MlKem)



MlDsa(MlDsa)



SlhDsa(SlhDsa)

Implementations

Source

impl Algorithm

pub const COUNT: usize = 18

Total number of supported algorithms.

pub const KEM_COUNT: usize = MlKem::COUNT

Number of KEM algorithms.

pub const SIGNATURE_COUNT: usize

Number of signing algorithms.

pub const ALL: &'static [Algorithm]

All supported algorithms (18 total).

pub const ALL_KEMS: &'static [Algorithm]

All KEM algorithms.

pub const ALL_SIGNATURES: &'static [Algorithm]

All signing algorithms.

pub fn all() -> impl Iterator<Item = Algorithm>

Returns an iterator over all supported algorithms.

pub fn kems() -> impl Iterator<Item = Algorithm>

Returns an iterator over all KEM algorithms.

pub fn signatures() -> impl Iterator<Item = Algorithm>

Returns an iterator over all signing algorithms.

pub const fn as_str(&self) -> &'static str

Returns the algorithm name string.

pub const fn oid(&self) -> &'static str

Returns the OID in dotted notation.

pub const fn algorithm_type(&self) -> AlgorithmType

Returns the algorithm type.

pub const fn family(&self) -> AlgorithmFamily

Returns the algorithm family.

pub const fn security_level(&self) -> SecurityLevel

Returns the NIST security level.

pub const fn public_key_size(&self) -> usize

Returns the public key size in bytes.

pub const fn private_key_size(&self) -> usize

Returns the private key size in bytes.

pub const fn info(&self) -> AlgorithmInfo

Returns the complete algorithm info.

pub fn from_oid(oid: &str) -> Result<Algorithm, Error>

Parse from an OID string.

pub const fn as_ml_kem(&self) -> Option<MlKem>

Returns this as an MlKem if it is one.

pub const fn as_ml_dsa(&self) -> Option<MlDsa>

Returns this as an MlDsa if it is one.

pub const fn as_slh_dsa(&self) -> Option<SlhDsa>

Returns this as an SlhDsa if it is one.